@@ -14,7 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from collections import Counter
+import collections
 
 from bandit.core import constants
 
@@ -67,16 +67,16 @@ class Metrics(object):
         """
         def proc(line):
             tmp = line.strip()
-            return tmp and not tmp.startswith('#')
+            return bool(tmp and not tmp.startswith(b'#'))
 
-        self.current['loc'] += len(list(filter(proc, lines)))
+        self.current['loc'] += sum(proc(line) for line in lines)
 
     def count_issues(self, scores):
         self.current.update(self._get_issue_counts(scores))
 
     def aggregate(self):
         """Do final aggregation of metrics."""
-        c = Counter()
+        c = collections.Counter()
         for fname in self.data:
             c.update(self.data[fname])
         self.data['_totals'] = dict(c)
