@@ -21,17 +21,16 @@ import operator
 from bandit.core import constants
 from bandit.core import tester as b_tester
 from bandit.core import utils as b_utils
-from bandit.core.utils import InvalidModulePath
 
 
 logger = logging.getLogger(__name__)
 
 
 class BanditNodeVisitor(object):
-    def __init__(self, fname, config, metaast, testset,
-                 debug, ignore_nosec, metrics):
+    def __init__(self, fname, metaast, testset,
+                 debug, nosec_lines, metrics):
         self.debug = debug
-        self.ignore_nosec = ignore_nosec
+        self.nosec_lines = nosec_lines
         self.seen = 0
         self.scores = {
             'SEVERITY': [0] * len(constants.RANKING),
@@ -39,24 +38,21 @@ class BanditNodeVisitor(object):
         }
         self.depth = 0
         self.fname = fname
-        self.config = config
         self.metaast = metaast
         self.testset = testset
         self.imports = set()
         self.import_aliases = {}
         self.tester = b_tester.BanditTester(
-            self.config, self.testset, self.debug
-        )
+            self.testset, self.debug, nosec_lines)
 
         # in some cases we can't determine a qualified name
         try:
             self.namespace = b_utils.get_module_qualname_from_path(fname)
-        except InvalidModulePath:
+        except b_utils.InvalidModulePath:
             logger.info('Unable to find qualified name for module: %s',
                         self.fname)
             self.namespace = ""
         logger.debug('Module qualified name: %s', self.namespace)
-        self.lines = []
         self.metrics = metrics
 
     def visit_ClassDef(self, node):
@@ -194,12 +190,10 @@ class BanditNodeVisitor(object):
         if hasattr(node, 'lineno'):
             self.context['lineno'] = node.lineno
 
-            if not self.ignore_nosec:
-                if ("# nosec" in self.lines[node.lineno - 1] or
-                        "#nosec" in self.lines[node.lineno - 1]):
-                    logger.debug("skipped, nosec")
-                    self.metrics.note_nosec()
-                    return False
+            if node.lineno in self.nosec_lines:
+                logger.debug("skipped, nosec")
+                self.metrics.note_nosec()
+                return False
 
         self.context['node'] = node
         self.context['linerange'] = b_utils.linerange_fix(node)
@@ -273,14 +267,13 @@ class BanditNodeVisitor(object):
                 operator.add, self.scores[score_type], scores[score_type]
             ))
 
-    def process(self, lines):
+    def process(self, data):
         '''Main process loop
 
         Build and process the AST
         :param lines: lines code to process
         :return score: the aggregated score for the current file
         '''
-        self.lines = lines
-        f_ast = ast.parse("".join(self.lines))
+        f_ast = ast.parse(data)
         self.generic_visit(f_ast)
         return self.scores
