@@ -13,10 +13,10 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-from collections import OrderedDict
+import collections
 import tempfile
 
-from bs4 import BeautifulSoup
+import bs4
 import mock
 import testtools
 
@@ -41,11 +41,12 @@ class HtmlFormatterTests(testtools.TestCase):
     def test_report_with_skipped(self):
         self.manager.skipped = [('abc.py', 'File is bad')]
 
+        tmp_file = open(self.tmp_fname, 'w')
         b_html.report(
-            self.manager, self.tmp_fname, bandit.LOW, bandit.LOW)
+            self.manager, tmp_file, bandit.LOW, bandit.LOW)
 
         with open(self.tmp_fname) as f:
-            soup = BeautifulSoup(f.read(), 'html.parser')
+            soup = bs4.BeautifulSoup(f.read(), 'html.parser')
             skipped_span = soup.find_all('span', id='skipped')[0]
 
             self.assertEqual(1, len(soup.find_all('span', id='skipped')))
@@ -73,16 +74,16 @@ class HtmlFormatterTests(testtools.TestCase):
 
         issue_y = _get_issue_instance()
 
-        get_issue_list.return_value = OrderedDict([(issue_a, [issue_x,
-                                                              issue_y]),
-                                                   (issue_b, [issue_x]),
-                                                   (issue_c, [issue_y])])
+        get_issue_list.return_value = collections.OrderedDict(
+            [(issue_a, [issue_x, issue_y]),
+             (issue_b, [issue_x]), (issue_c, [issue_y])])
 
+        tmp_file = open(self.tmp_fname, 'w')
         b_html.report(
-            self.manager, self.tmp_fname, bandit.LOW, bandit.LOW)
+            self.manager, tmp_file, bandit.LOW, bandit.LOW)
 
         with open(self.tmp_fname) as f:
-            soup = BeautifulSoup(f.read(), 'html.parser')
+            soup = bs4.BeautifulSoup(f.read(), 'html.parser')
 
             self.assertEqual('1000', soup.find_all('span', id='loc')[0].text)
             self.assertEqual('50', soup.find_all('span', id='nosec')[0].text)
@@ -126,6 +127,26 @@ class HtmlFormatterTests(testtools.TestCase):
             self.assertIn('CCCCCCC', issue1.text)
             self.assertIn('abc.py', issue1.text)
 
+    @mock.patch('bandit.core.issue.Issue.get_code')
+    @mock.patch('bandit.core.manager.BanditManager.get_issue_list')
+    def test_escaping(self, get_issue_list, get_code):
+        self.manager.metrics.data['_totals'] = {'loc': 1000, 'nosec': 50}
+        marker = '<tag in code>'
+
+        issue_a = _get_issue_instance()
+        issue_x = _get_issue_instance()
+        get_code.return_value = marker
+
+        get_issue_list.return_value = {issue_a: [issue_x]}
+
+        tmp_file = open(self.tmp_fname, 'w')
+        b_html.report(
+            self.manager, tmp_file, bandit.LOW, bandit.LOW)
+
+        with open(self.tmp_fname) as f:
+            contents = f.read()
+        self.assertNotIn(marker, contents)
+
 
 def _get_issue_instance(severity=bandit.MEDIUM, confidence=bandit.MEDIUM):
     new_issue = issue.Issue(severity, confidence, 'Test issue')
