@@ -13,7 +13,7 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-from collections import OrderedDict
+import collections
 import tempfile
 
 import mock
@@ -77,9 +77,10 @@ class ScreenFormatterTests(testtools.TestCase):
         (tmp_fd, self.tmp_fname) = tempfile.mkstemp()
         self.manager.out_file = self.tmp_fname
 
-        get_issue_list.return_value = OrderedDict()
+        get_issue_list.return_value = collections.OrderedDict()
         with mock.patch('bandit.formatters.screen.do_print') as m:
-            screen.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+            tmp_file = open(self.tmp_fname, 'w')
+            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                           lines=5)
             self.assertIn('No issues identified.',
                           '\n'.join([str(a) for a in m.call_args]))
@@ -117,7 +118,8 @@ class ScreenFormatterTests(testtools.TestCase):
         with mock.patch(output_str_fn) as output_str:
             output_str.return_value = 'ISSUE_OUTPUT_TEXT'
 
-            screen.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+            tmp_file = open(self.tmp_fname, 'w')
+            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                           lines=5)
 
             calls = [mock.call(issue_a, '', lines=5),
@@ -128,7 +130,8 @@ class ScreenFormatterTests(testtools.TestCase):
         # Validate that we're outputting all of the expected fields and the
         # correct values
         with mock.patch('bandit.formatters.screen.do_print') as m:
-            screen.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+            tmp_file = open(self.tmp_fname, 'w')
+            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                           lines=5)
 
             data = '\n'.join([str(a) for a in m.call_args[0][0]])
@@ -180,9 +183,8 @@ class ScreenFormatterTests(testtools.TestCase):
         issue_z = _get_issue_instance()
         issue_z.fname = 'z'
 
-        get_issue_list.return_value = OrderedDict([(issue_a, [issue_x]),
-                                                   (issue_b, [issue_y,
-                                                              issue_z])])
+        get_issue_list.return_value = collections.OrderedDict(
+            [(issue_a, [issue_x]), (issue_b, [issue_y, issue_z])])
 
         # Validate that we're outputting the correct issues
         indent_val = ' ' * 10
@@ -190,7 +192,8 @@ class ScreenFormatterTests(testtools.TestCase):
         with mock.patch(output_str_fn) as output_str:
             output_str.return_value = 'ISSUE_OUTPUT_TEXT'
 
-            screen.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+            tmp_file = open(self.tmp_fname, 'w')
+            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                           lines=5)
 
             calls = [mock.call(issue_a, '', lines=5),
